@@ -67,6 +67,13 @@ class Segment(metaclass=abc.ABCMeta):
         The end address of the segment (non-inclusive).
         """
 
+    @property
+    @abc.abstractmethod
+    def initialized(self) -> bool:
+        """
+        Returns True if we have initialized bytes in the segment.
+        """
+
     @property
     @abc.abstractmethod
     def bit_size(self) -> int:
@@ -98,6 +105,8 @@ class Segment(metaclass=abc.ABCMeta):
 
         Defaults to consuming all of the data stream.
         """
+        if not self.initialized:
+            return b""
         with self.open() as stream:
             return stream.read()
 
@@ -110,6 +119,8 @@ class Segment(metaclass=abc.ABCMeta):
         :return: Raw bytes from the segment
         :raises IOError: If address is not within the segment.
         """
+        if not self.initialized:
+            return b""
         with self.open() as stream:
             stream.seek_address(addr)
             return stream.read(length)
